@@ -1,4 +1,4 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from xmlrunner import XMLTestRunner
+from .xmlrunner import XMLTestRunner
 
